@@ -236,13 +236,14 @@ class Config():
                   (configParser.getboolean, "autoupdate", False),
                   (configParser.getboolean, "woodchuck", True),
                   (configParser.getboolean, "askedAboutWoodchuck", False),
-                  (configParser.getint, "updateInterval", 4),
+                  (configParser.getfloat, "updateInterval", 4),
                   (configParser.get, "orientation", "Automatic"),
                   (configParser.getboolean, "imageCache", False),
                   (configParser.getboolean, "proxy", True),
                   (configParser.getboolean, "hidereadfeeds", False),
                   (configParser.getboolean, "hidereadarticles", False),
                   (configParser.getboolean, "extBrowser", False),
+                  (configParser.getboolean, "theme", True),
                   (configParser.get, "feedsort", "Manual"))
 
         for fetcher, name, default in values:
@@ -270,6 +271,7 @@ class Config():
         configParser.set(section, 'hidereadarticles', str(self.config["hidereadarticles"]))
         configParser.set(section, 'extBrowser', str(self.config["extBrowser"]))
         configParser.set(section, 'feedsort', str(self.config["feedsort"]))
+        configParser.set(section, 'theme', str(self.config["theme"]))
 
         # Writing our configuration file
         file = open(self.configFilename, 'wb')
@@ -299,8 +301,12 @@ class Config():
         return self.config["artFontSize"]
     def getExpiry(self):
         return self.config["expiry"]
+    def setExpiry(self, expiry):
+        self.config["expiry"] = expiry
     def isAutoUpdateEnabled(self):
         return self.config["autoupdate"]
+    def setAutoUpdateEnabled(self, value):
+        self.config["autoupdate"] = value
     def getWoodchuckEnabled(self):
         return self.config["woodchuck"]
     def getAskedAboutWoodchuck(self):
@@ -316,8 +322,14 @@ class Config():
         return "sans %s" % self.config["fontSize"]
     def getOrientation(self):
         return ranges["orientation"].index(self.config["orientation"])
+    def getOrientationChoices(self):
+        return ranges["orientation"]
+    def setOrientation(self, choice):
+        self.config["orientation"] = index 
     def getImageCache(self):
         return self.config["imageCache"]
+    def setImageCache(self, cache):
+        self.config["imageCache"] = bool(cache) 
     @mainthread
     def getProxy(self):
         if self.config["proxy"] == False:
@@ -330,9 +342,21 @@ class Config():
         return (False, None)
     def getHideReadFeeds(self):
         return self.config["hidereadfeeds"]
+    def setHideReadFeeds(self, setting):
+        self.config["hidereadfeeds"] = bool(setting)
     def getHideReadArticles(self):
         return self.config["hidereadarticles"]
+    def setHideReadArticles(self, setting):
+        self.config["hidereadarticles"] = bool(setting)
     def getOpenInExternalBrowser(self):
         return self.config["extBrowser"]
     def getFeedSortOrder(self):
         return self.config["feedsort"]
+    def getFeedSortOrderChoices(self):
+        return ranges["feedsort"]
+    def setFeedSortOrder(self, setting):
+        self.config["feedsort"] = setting
+    def getTheme(self):
+        return self.config["theme"]
+    def setTheme(self, theme):
+        self.config["theme"] = bool(theme)
