@@ -46,7 +46,7 @@ debugging.init(dot_directory=".feedingit", program_name="update_feeds")
 
 from updatedbus import update_server_object
 
-CONFIGDIR="/home/user/.feedingit/"
+CONFIGDIR = os.environ.get("HOME", "/home/user") + "/.feedingit/"
 #DESKTOP_FILE = "/usr/share/applications/hildon-status-menu/feedingit_status.desktop"
 
 from socket import setdefaulttimeout
